package com.mingxue.spider.utils;

import java.io.IOException;

import com.mingxue.spider.helper.StringUtils;
import com.sun.org.apache.xpath.internal.operations.Bool;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.mingxue.spider.dto.User;

import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.FormBody;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;

public class ApiUtil {
    private static Logger log = LoggerFactory.getLogger(ApiUtil.class);
    private static ApiUtil instance;
    private OkHttpClient.Builder builder;
    private Request.Builder requestBuilder;
    private OkHttpClient okHttpClient;
    private User user;

    private ApiUtil() {
        builder = new OkHttpClient.Builder();
        okHttpClient = builder.addInterceptor(new RequestLoggerInterceptor()).addInterceptor(new ResponseLoggerInterceptor()).build();
        requestBuilder = new Request.Builder();// 省的每次都new request操作,直接builder出来,随后需要什么往里加,build出来即可
    }

    public static ApiUtil getInstance() {
        if (null == instance) {
            synchronized (ApiUtil.class) {
                if (null == instance) {
                    instance = new ApiUtil();
                }
            }
        }
        return instance;
    }

    public User getUser() {
        return user;
    }

    public void httpGet(String url, final Callback callback) {
        Request request = requestBuilder.url(url).build();
        okHttpClient.newCall(request).enqueue(callback);
    }

    private void httpGetHtml(String url) throws IOException {
        Request request = requestBuilder.url(url).build();
        okHttpClient.newCall(request).execute();
    }

    public JSONObject httpSyncGet(String url) throws IOException {
        Request request = requestBuilder.url(url).build();
        final Response res = okHttpClient.newCall(request).execute();
        JSONObject obj = JSON.parseObject(res.body().string());
        if (400 == obj.getIntValue("error")) {
            this.login();
            return httpSyncGet(url);
        } else {
            return obj;
        }
    }

    public void httpPost(String urlString, FormBody formBody, Callback callback) {
        Request request = requestBuilder.url(urlString).method("POST", formBody).build();
        okHttpClient.newCall(request).enqueue(callback);
    }

    /**
     * 第一高考网 http://www.diyigaokao.com/
     * @param user
     */
    public Boolean login(User user) {
        try {
            log.error("user is start login： {}",JSONObject.toJSONString(user));
            String url= StringUtils.EMPTY;
            String host= StringUtils.EMPTY;
            if(user.getIsHn()){
                url = "http://jlzy.zljy33.com/";
                host="jlzy.zljy33.com";
            }else{
                url = "http://www.diyigaokao.com/";
                host="www.diyigaokao.com";
            }
            httpGetHtml(url);
            this.user = user;
            JSONObject res = httpSyncGet("https://apiv4.diyigaokao.com/index/dailiConfig?host="+host);
            Integer dailiId = res.getJSONObject("data").getInteger("id");
            StringBuilder sb = new StringBuilder();
            sb.append("https://apiv4.diyigaokao.com/login?uuid=agentpc&platform=pc");
            sb.append("&dailiId=").append(dailiId);
            sb.append("&userName=").append(user.getCode()).append("&password=").append(user.getPassword());
            res = httpSyncGet(sb.toString());
            if (0 == res.getIntValue("error")) {
                JSONObject data = res.getJSONObject("data");
                Integer provinceId = data.getInteger("provinceId");
                String token = data.getString("accessToken");
                requestBuilder.addHeader("accessToken", token);
                this.user.setProvinceId(provinceId).setToken(token);
                Integer utype = data.getInteger("utype");
                if(utype!=8){
                    log.error("user is not valid： {}",JSONObject.toJSONString(user));
                    //全能卡用户
                    return false;
                }
                if(utype==1){
                    //普通用户
                    return false;
                }

                return true;
            } else {
                System.out.println(res);
                return false;
            }
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }

    /**
     * 登录系统:湖南 http://jlzy.zljy33.com/
     * @return
     */
    public void login() {
        while (true){
            Boolean isSuccess = login(UserUtil.next());
            if(isSuccess){
                //登录成功后跳转
                break;
            }else {
                //登录失败后重复调用
                login();
            }
        }
    }

    public Boolean login(String code, String password, Boolean isHn) {
        return login(new User().setCode(code).setPassword(password).setIsHn(isHn));
    }

    /**
     * 请求拦截器
     */
    static class RequestLoggerInterceptor implements Interceptor {

        @Override
        public Response intercept(Chain chain) throws IOException {
            Request request = chain.request();
            log.debug(this.getClass().getSimpleName(), "url    =  : " + request.url());
            log.debug(this.getClass().getSimpleName(), "method =  : " + request.method());
            log.debug(this.getClass().getSimpleName(), "headers=  : " + request.headers());
            log.debug(this.getClass().getSimpleName(), "body   =  : " + request.body());
            return chain.proceed(request);
        }
    }

    /**
     * 响应拦截器
     */
    static class ResponseLoggerInterceptor implements Interceptor {
        @Override
        public Response intercept(Chain chain) throws IOException {
            Response response = chain.proceed(chain.request());
            log.debug(this.getClass().getSimpleName(), "code    =  : " + response.code());
            log.debug(this.getClass().getSimpleName(), "message =  : " + response.message());
            log.debug(this.getClass().getSimpleName(), "protocol=  : " + response.protocol());
            if (response.body() != null && response.body().contentType() != null) {
                MediaType mediaType = response.body().contentType();
                String string = response.body().string();
                log.debug(this.getClass().getSimpleName(), "mediaType=  :  " + mediaType.toString());
                log.debug(this.getClass().getSimpleName(), "string   =  : " + string);
                ResponseBody responseBody = ResponseBody.create(mediaType, string);
                return response.newBuilder().body(responseBody).build();
            } else {
                return response;
            }
        }
    }

    public static class CallbackAdapter implements Callback {

        @Override
        public void onFailure(Call call, IOException e) {

        }

        @Override
        public void onResponse(Call call, Response res) throws IOException {
            success(res);
        }

        public void success(Response res) {}

    }

}
